@@ -32,7 +32,7 @@
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
-#define MediaInfo_Version_GUI __T("25.09.20251103")
+#define MediaInfo_Version_GUI __T("25.10.20251107")
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -94,10 +94,6 @@ public:
     ZenLib::ZtringListList  SponsorUrl;
     ZenLib::ZtringListList  SponsorBanner;
     ZenLib::ZtringListList  SponsorBannerClickUrl;
-    ZenLib::ZtringListList  SponsorMessageWeight;
-    ZenLib::ZtringListList  SponsorBannerWeight;
-    size_t                  SponsorMessageIndex;
-    size_t                  SponsorBannerIndex;
 
     //Plugins
     ZenLib::Ztring GraphPluginURL;
